<?php
/**
* Customizer default options
*
* @package Theme Palace
* @subpackage enlightme Pro
* @since enlightme Pro 1.0.0
* @return array An array of default values
*/

function enlightme_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$enlightme_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2c2d39',
		'header_tagline_color'			=> '#990f12',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#990f12',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',

		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		// loader
		'loader_enable'         		=> (bool) false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> (bool) true,
		'breadcrumb_separator'			=> '/',

		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> (bool) true,
		'menu_search'					=> (bool) true,

		// excerpt options
		'long_excerpt_length'           => 25,

		// pagination options
		'pagination_enable'         	=> (bool) true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'enlightme-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> (bool) true,

		// reset options
		'reset_options'      			=> (bool) false,

		// homepage options
		'enable_frontpage_content' 		=> (bool) false,

		// homepage sections sortable
		'all_sortable'	=> 'slider,service,about,career,testimonial,subscription,blog,promotion,team,gallery,counter,medical_featured,featured,client,download,featured_products,recent_products,cta,latest_products,latest_posts,featured_posts,popular_posts,advertisement,blog_posts',

		'default_sortable'	=> 'slider,service,about,career,testimonial,subscription,blog,team,gallery,featured,client,download',

		'second_sortable'	=> 'slider,featured_products,recent_products,cta,about,latest_products,testimonial,subscription,latest_posts',

		'third_sortable'	=> 'slider,featured_posts,popular_posts,advertisement,recent_products,blog_posts,gallery,client',

		'fourth_sortable'	=> 'slider,service,about,promotion,team,gallery,counter,testimonial,latest_posts,client',

		'fifth_sortable'	=> 'slider,service,about,counter,medical_featured,promotion,subscription,team,recent_products,gallery,testimonial,latest_posts,client',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'enlightme-pro' ),
		'hide_date' 					=> (bool) false,
		'hide_image'					=> (bool) false,
		'hide_category'					=> (bool) false,
		'hide_author'					=> (bool) false,
		'hide_title'					=> (bool) false,
		'hide_description'				=> (bool) false,

		// single post theme options
		'single_post_hide_date' 		=> (bool) false,
		'single_post_hide_author'		=> (bool) false,
		'single_post_hide_category'		=> (bool) false,
		'single_post_hide_tags'			=> (bool) false,
		'single_post_hide_image'		=> (bool) false,
		'single_post_hide_description'	=> (bool) false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> (bool) true,
		'topbar_btn'				=> (bool) true,
		'social_menu_enable'			=> (bool) true,
		'topbar_btn_title'				=> esc_html__( 'Apply', 'enlightme-pro' ),
		'topbar_btn_url'				=> esc_html__( '#', 'enlightme-pro' ),
		'topbar_field_1'				=> esc_html__( ' 123 456 7891', 'enlightme-pro' ),
		'topbar_field_2'				=> esc_html__( 'info@enlightme.com', 'enlightme-pro' ),

		// slider
		'slider_section_enable'			=> (bool) true,
		'slider_content_type'			=> 'post',
		'slider_autoplay'				=> (bool) false,
		'slider_count'					=> 3,
		'slider_excerpt_length'			=> 25,
		'slider_sub_title'				=> esc_html__( 'Start Learning Now', 'enlightme-pro' ),
		'slider_btn_label'				=> esc_html__( 'Find your course', 'enlightme-pro' ),

		//service 
		'service_section_enable'		=> (bool) true,
		'service_content_type'			=> 'post',
		'service_title'					=> esc_html__( 'Learn From People Around you', 'enlightme-pro' ),
		'service_sub_title'				=> esc_html__( 'Get Started!', 'enlightme-pro' ),
		'service_description'			=> esc_html__( 'While college tuition more than tripled over the past 30 years, the value of a college degree gradually fell due to credential inflation. As more people get degrees, what used to be a unique achievement becomes trivial.', 'enlightme-pro' ),
		'service_btn'					=> esc_html__( 'Read More', 'enlightme-pro' ),
		'service_count'					=> 4,
		'service_excerpt_length'		=> 20,

		//about 
		'about_section_enable'		=> (bool) true,
		'about_excerpt_length'		=> 30,
		'about_content_type'		=> 'post',
		'about_sub_title'			=> esc_html__( 'About Us', 'enlightme-pro' ),
		'about_btn_text'			=> esc_html__( 'I Want TO Learn More', 'enlightme-pro' ),
		'about_video_intro_text'	=> esc_html__( 'Watch intro video about our system:', 'enlightme-pro' ),
		'about_video_sub_intro_text'			=> esc_html__( 'We are here to create a history!!', 'enlightme-pro' ),

		// testimonial
		'testimonial_section_enable'					=> (bool) true,
		'testimonial_section_link_enable'				=> (bool) false,
		'testimonial_content_type'						=> 'page',
		'testimonial_count'								=> 4,
		'testimonial_excerpt_length'					=> 25,
		'testimonial_section_autoplay_slider_enable'	=> (bool) true,
		'testimonial_section_buttom_slider_enable'		=> (bool) true,
		'testimonial_sub_title'							=> esc_html__( 'Testimonials', 'enlightme-pro' ),
		'testimonial_title'								=> esc_html__( 'What Happy People Said About Enlightme', 'enlightme-pro' ),

		// subscription
		'subscription_section_enable'	=> (bool) true,
		'subscription_title'			=> esc_html__( 'Get 20% off in Your First Course', 'enlightme-pro' ),
		'subscription_description'		=> esc_html__( 'Enter your email address below to receive your discount code. Your email address', 'enlightme-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'enlightme-pro' ),

		// blog
		'blog_section_enable'			=> (bool) true,
		'blog_content_type'				=> 'post',
		'blog_count'					=> 4,
		'blog_excerpt_length'			=> 25,
		'blog_title'					=> esc_html__( 'Know What’s Going on Around Us', 'enlightme-pro' ),
		'blog_sub_title'				=> esc_html__( 'Latest Articles', 'enlightme-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'enlightme-pro' ),

		//team 
		'team_section_enable'					=> (bool) true,
		'team_content_type'						=> 'page',
		'team_count'							=> 5,
		'team_section_autoplay_slider_enable'	=> (bool) true,
		'team_section_buttom_slider_enable'		=> (bool) true,
		'team_title'							=> esc_html__( 'Our Team Members', 'enlightme-pro' ),
		'team_sub_title'						=> esc_html__( 'We Are Family', 'enlightme-pro' ),	
		'team_button'							=> esc_html__( 'View Detail', 'enlightme-pro' ),	

		// gallery slider
		'gallery_section_enable'		=> (bool) true,
		'gallery_content_type'			=> 'post',
		'gallery_autoplay'				=> (bool) true,
		'gallery_count'					=> 4,
		'gallery_title'					=> esc_html__( 'Breaking Boundaries', 'enlightme-pro' ),
		'gallery_sub_title'				=> esc_html__( 'Our Gallery', 'enlightme-pro' ),

		//featured
		'featured_section_enable'		=> (bool) true,
		'featured_count'				=> 3,
		'featured_excerpt_length'		=> 30,
		'featured_btn_title'			=> esc_html__( 'More Our Features', 'enlightme-pro' ),
		'featured_content_type'			=> 'post',
		'featured_col_layout'			=> 'col-3',

		// client
		'client_section_enable'			=> (bool) true,
		'client_content_type'			=> 'page',
		'client_count'					=> 6,
		'client_title'					=> esc_html__( 'Many peope use Enlightme to enrich their brand & business.', 'enlightme-pro' ),

		// career
		'career_section_enable'			=> (bool) true,
		'career_autoplay'				=> (bool) false,
		'career_content_type'			=> 'category',
		'career_count'					=> 5,
		'career_sub_title'				=> esc_html__( 'New Opportunities', 'enlightme-pro' ),
		'career_title'					=> esc_html__( 'Choose Careers', 'enlightme-pro' ),
		'career_btn_title'				=> esc_html__( 'Explore all courses', 'enlightme-pro' ),
		'career_post_btn'				=> esc_html__( 'Join Course', 'enlightme-pro' ),

		// featured_products
		'featured_products_section_enable'	=> (bool) true,
		'featured_products_count'				=> 3,

		//recent products
		'recent_products_section_enable'	=> (bool) true,
		'recent_products_content_type'		=> 'product-category',
		'recent_products_count'			=> 4,
		'recent_products_title'			=> esc_html__( 'Popular Products', 'enlightme-pro' ),
		'recent_products_sub_title'		=> esc_html__( 'Sale', 'enlightme-pro' ),

		//cta 
		'cta_section_enable'		=> true,
		'cta_content_type'			=> 'custom',
		'cta_title'					=> esc_html__( 'How to Wear a Headscarf Like a Gucci Muse', 'enlightme-pro' ),
		'cta_sub_title'				=> esc_html__( 'All Products', 'enlightme-pro' ),
		'cta_btn_title'				=> esc_html__( 'Explore More', 'enlightme-pro' ),

		//latest products
		'latest_products_section_enable'	=> (bool) true,
		'latest_products_content_type'		=> 'product-category',
		'latest_products_count'			=> 4,
		'latest_products_title'			=> esc_html__( 'Latest Products', 'enlightme-pro' ),
		'latest_products_sub_title'		=> esc_html__( 'Trending', 'enlightme-pro' ),

		//latest_posts
		'latest_posts_section_enable'	=> (bool) true,
		'latest_posts_content_type'		=> 'post',
		'latest_posts_count'			=> 3,
		'latest_posts_excerpt_length'	=> 25,
		'latest_posts_sub_title'		=> esc_html__( 'ARTICLE', 'enlightme-pro' ),
		'latest_posts_title'			=> esc_html__( 'OUR LATEST NEWS', 'enlightme-pro' ),

		//featured_posts
		'featured_posts_section_enable'		=> (bool) true,
		'featured_posts_count'				=> 3,
		'featured_posts_content_type'			=> 'post',
		'featured_posts_col_layout'			=> 'col-3',

		//popular_posts
		'popular_posts_section_enable'	=> (bool) true,
		'popular_posts_content_type'	=> 'post',
		'popular_posts_count'			=> 3,
		'popular_posts_excerpt_length'	=> 25,
		'popular_posts_sub_title'		=> esc_html__( 'Popular Post', 'enlightme-pro' ),
		'popular_posts_title'			=> esc_html__( 'What Happy People Said About Enlightme', 'enlightme-pro' ),
		'popular_posts_btn'				=> esc_html__( 'Learn More', 'enlightme-pro' ),

		//advertisement
		'advertisement_section_enable'	=> (bool) true,

		//blog_posts
		'blog_posts_section_enable'		=> (bool) true,
		'blog_posts_content_type'		=> 'post',
		'blog_posts_count'				=> 3,
		'blog_posts_excerpt_length'		=> 25,
		'blog_posts_sub_title'			=> esc_html__( 'Latest Post', 'enlightme-pro' ),
		'blog_posts_title'				=> esc_html__( 'What Happy People Said About Enlightme', 'enlightme-pro' ),
		'blog_posts_btn'				=> esc_html__( 'Continue Reading', 'enlightme-pro' ),

		//promotion
		'promotion_section_enable'		=> (bool) true,
		'promotion_excerpt_length'		=> 25,
		'promotion_content_type'		=> 'page',
		'promotion_title'				=> esc_html__( 'Providing Medical Care for the Sickest', 'enlightme-pro' ),
		'promotion_description'			=> esc_html__( 'Dentistry, also known as dental medicine and ‘oral medicine, is a branch of medicine that consists of the study, diagnosis, prevention, and treatment.', 'enlightme-pro' ),
		'promotion_button'				=> esc_html__( 'Get A Quote', 'enlightme-pro' ),

		// counter
		'counter_section_enable'		=> (bool) true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		// medical_featured
		'medical_featured_section_enable'		=> (bool) true,
		'medical_featured_content_type'			=> 'post',
		'medical_featured_count'				=> 3,

		//download 
		'download_section_enable'		=> (bool) true,
		'download_content_type'			=> 'page',
		'download_title'				=> esc_html__( 'Download Enlightme app from Google And Apple app store for free!', 'enlightme-pro' ),
		'download_sub_title'			=> esc_html__( 'What are you waiting for?', 'enlightme-pro' ),

		//footer
		'footer_text'					=> esc_html__( 'Join thousands of learners making a difference every day using Enlightme.', 'enlightme-pro' ),
		'footer_btn_title'				=> esc_html__( 'Explore a free course', 'enlightme-pro' ),

		);

$output = apply_filters( 'enlightme_pro_default_theme_options', $enlightme_pro_default_options );

// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}