<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'enlightme_pro_about_section', array(
	'title'             => esc_html__( 'About Us','enlightme-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_default_layout( $control )
            ||
            enlightme_pro_is_second_layout( $control )
            ||
            enlightme_pro_is_fourth_layout( $control )
            ||
            enlightme_pro_is_fifth_layout( $control )
        );
    },
) );

// About content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_about_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[about_section_enable]',
    ) );
}

// about title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us p.section-subtitle',
		'settings'            => 'enlightme_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_about_sub_title_partial',
    ) );
}

// about title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_btn_text]', array(
	'label'           	=> esc_html__( 'Button Label', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[about_btn_text]', array(
		'selector'            => '#about-us div.read-more a',
		'settings'            => 'enlightme_pro_theme_options[about_btn_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_about_btn_text_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_excerpt_length]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_long_excerpt',
	'default'			=> $options['about_excerpt_length'],
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'enlightme-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'enlightme-pro' ),
	'section'     		=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// About content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'enlightme-pro' ),
		'post' 		=> esc_html__( 'Post', 'enlightme-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_page',
) );

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_about_section',
	'choices'			=> enlightme_pro_page_choices(),
	'active_callback'	=> 'enlightme_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_page',
) );

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_about_section',
	'choices'			=> enlightme_pro_post_choices(),
	'active_callback'	=> 'enlightme_pro_is_about_section_content_post_enable',
) ) );

// about description setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_video_intro_text]', array(
	'sanitize_callback' => 'enlightme_pro_santize_allow_tag',
	'default'			=> $options['about_video_intro_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_video_intro_text]', array(
	'label'           	=> esc_html__( 'Video Intro Text', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[about_video_intro_text]', array(
		'selector'            => '#about-us h2.entry-title',
		'settings'            => 'enlightme_pro_theme_options[about_video_intro_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_about_video_intro_text_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_video_sub_intro_text]', array(
	'sanitize_callback' => 'enlightme_pro_santize_allow_tag',
	'default'			=> $options['about_video_sub_intro_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_video_sub_intro_text]', array(
	'label'           	=> esc_html__( 'Video Intro Sub Text', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[about_video_sub_intro_text]', array(
		'selector'            => '#about-us .entry-header p',
		'settings'            => 'enlightme_pro_theme_options[about_video_sub_intro_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_about_video_sub_intro_text_partial',
    ) );
}

// about image setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_featured_image]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'enlightme_pro_theme_options[about_featured_image]',
		array(
		'label'       		=> esc_html__( 'Featured Image', 'enlightme-pro' ),
		'section'     		=> 'enlightme_pro_about_section',
		'active_callback'	=> 'enlightme_pro_is_about_section_enable',
) ) );

// about image setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_video_image]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'enlightme_pro_theme_options[about_video_image]',
		array(
		'label'       		=> esc_html__( 'Video Featured Image', 'enlightme-pro' ),
		'section'     		=> 'enlightme_pro_about_section',
		'active_callback'	=> 'enlightme_pro_is_about_section_enable',
) ) );

// about btn link setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[about_video_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[about_video_link]', array(
	'label'           	=> esc_html__( 'Youtube Video Link', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_about_section',
	'active_callback' 	=> 'enlightme_pro_is_about_section_enable',
	'type'				=> 'url',
) );
