<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'enlightme_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','enlightme-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_fourth_layout( $control )
            ||
            enlightme_pro_is_fifth_layout( $control )
        );
    },
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_counter_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[counter_section_enable]', array(
        'selector'            => '#counter-section .tooltiptext',
        'settings'            => 'enlightme_pro_theme_options[counter_section_enable]',
    ) );
}

// counter content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_counter_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'enlightme-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'enlightme-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'enlightme-pro' ),
	),
) );

$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'enlightme_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'enlightme-pro' ),
		'section'     		=> 'enlightme_pro_counter_section',
		'active_callback'	=> 'enlightme_pro_is_counter_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_counter_count',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_counter_section',
	'active_callback'   => 'enlightme_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter note control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Icon_Picker( $wp_customize, 'enlightme_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_counter_section',
		'active_callback'	=> 'enlightme_pro_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'enlightme_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'enlightme-pro' ), $i ),
		'section'        	=> 'enlightme_pro_counter_section',
		'active_callback' 	=> 'enlightme_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'enlightme_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'enlightme-pro' ), $i ),
		'section'        	=> 'enlightme_pro_counter_section',
		'active_callback' 	=> 'enlightme_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'enlightme_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Enlightme_Pro_Customize_Horizontal_Line( $wp_customize, 'enlightme_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'enlightme_pro_counter_section',
			'active_callback' => 'enlightme_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;