<?php
/**
 * featured_products Section options
 *
 * @package Theme Palace
 * @subpackage Enlightme Pro
 * @since Enlightme Pro 1.0.0
 */

if ( !class_exists('WooCommerce') ) {
    return;
}

// Add featured_products section
$wp_customize->add_section( 'enlightme_pro_featured_products_section', array(
	'title'             => esc_html__( 'Featured Products','enlightme-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	enlightme_pro_is_second_layout( $control )
        );
    },
) );

// featured_products content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[featured_products_section_enable]', array(
	'default'			=> 	$options['featured_products_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[featured_products_section_enable]', array(
	'label'             => esc_html__( 'Featured Products Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_featured_products_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[featured_products_section_enable]', array(
		'selector'            => '#featured-products .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[featured_products_section_enable]',
    ) );
}

// Servuce count number control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[featured_products_count]', array(
	'default'          	=> $options['featured_products_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_featured_products_count',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[featured_products_count]', array(
	'label'             => esc_html__( 'Number of Featured Productss Posts', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_featured_products_section',
	'active_callback'   => 'enlightme_pro_is_featured_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['featured_products_count']; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'enlightme_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
		) ) ;

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Taxonomies_Control( $wp_customize,'enlightme_pro_theme_options[featured_products_content_featured_products_category_'.$i.']', array(
	'label'             => sprintf( esc_html__( 'Select Featured Products Category %d', 'enlightme-pro' ), $i ),
	'section'           => 'enlightme_pro_featured_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'enlightme_pro_is_featured_products_section_enable'
	) ) );

// featured_products title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[featured_products_sub_title_'.$i.']', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[featured_products_sub_title_'.$i.']', array(
	'label'             => sprintf( esc_html__( 'Sub Title %d', 'enlightme-pro' ), $i ),
	'section'        	=> 'enlightme_pro_featured_products_section',
	'active_callback' 	=> 'enlightme_pro_is_featured_products_section_enable',
	'type'				=> 'text',
) );

endfor;