<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Enlightme Pro
 * @since Enlightme Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'enlightme_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery Slider','enlightme-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_default_layout( $control )
            ||
            enlightme_pro_is_third_layout( $control )
            ||
            enlightme_pro_is_fourth_layout( $control )
            ||
            enlightme_pro_is_fifth_layout( $control )
        );
    },
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_gallery_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#gallery .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[gallery_section_enable]',
    ) );
}

// Gallery content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_autoplay]', array(
	'default'			=> 	$options['gallery_autoplay'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[gallery_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_gallery_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
	'active_callback' 	=> 'enlightme_pro_is_gallery_section_enable',
) ) );

$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Gallery Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_gallery_section',
	'active_callback' 	=> 'enlightme_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[gallery_title]', array(
		'selector'            => '#gallery h2.section-title',
		'settings'            => 'enlightme_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_gallery_title_partial',
    ) );
}

$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[gallery_sub_title]', array(
	'label'           	=> esc_html__( 'Gallery Sub Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_gallery_section',
	'active_callback' 	=> 'enlightme_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[gallery_sub_title]', array(
		'selector'            => '#gallery p.section-subtitle',
		'settings'            => 'enlightme_pro_theme_options[gallery_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_gallery_sub_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_gallery_section',
	'active_callback'   => 'enlightme_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_gallery_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'enlightme-pro' ),
		'post' 		=> esc_html__( 'Post', 'enlightme-pro' ),
		'category' 	=> esc_html__( 'Category', 'enlightme-pro' ),
	),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_gallery_section',
		'choices'			=> enlightme_pro_page_choices(),
		'active_callback'	=> 'enlightme_pro_is_gallery_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_gallery_section',
		'choices'			=> enlightme_pro_post_choices(),
		'active_callback'	=> 'enlightme_pro_is_gallery_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'enlightme_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Taxonomies_Control( $wp_customize,'enlightme_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'enlightme-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'enlightme_pro_is_gallery_section_content_category_enable'
) ) );