<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage Enlightme Pro
 * @since Enlightme Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'enlightme_pro_popular_posts_section', array(
	'title'             => esc_html__( 'Popular Posts','enlightme-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'enlightme-pro' ),
	'panel'				=> 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_third_layout( $control )
        );
    },

) );

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_section_enable]', array(
	'default'			=> 	$options['popular_posts_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[popular_posts_section_enable]', array(
	'label'             => esc_html__( 'Popular Posts Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_popular_posts_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[popular_posts_section_enable]', array(
		'selector'            => '#blog-popular-posts .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[popular_posts_section_enable]',
    ) );
}

// Popular Posts btn label setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_posts_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_sub_title]', array(
	'label'           	=> esc_html__( 'Section Sub Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_popular_posts_section',
	'active_callback' 	=> 'enlightme_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[popular_posts_sub_title]', array(
		'selector'            => '#blog-popular-posts p.section-subtitle',
		'settings'            => 'enlightme_pro_theme_options[popular_posts_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_popular_posts_sub_title_partial',
    ) );
}

// Popular Posts btn label setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_popular_posts_section',
	'active_callback' 	=> 'enlightme_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[popular_posts_title]', array(
		'selector'            => '#blog-popular-posts h2.section-title',
		'settings'            => 'enlightme_pro_theme_options[popular_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_popular_posts_title_partial',
    ) );
}

// Popular Posts btn label setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_btn]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_posts_btn'],
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_btn]', array(
	'label'           	=> esc_html__( 'Button Label', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_popular_posts_section',
	'active_callback' 	=> 'enlightme_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_count]', array(
	'default'          	=> $options['popular_posts_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_popular_posts_count',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_popular_posts_section',
	'active_callback'   => 'enlightme_pro_is_popular_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_excerpt_length]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_long_excerpt',
	'default'			=> $options['popular_posts_excerpt_length'],
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_excerpt_length]', array(
	'label'       		=> esc_html__( 'Blog Excerpt Length', 'enlightme-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in popular_posts posts.', 'enlightme-pro' ),
	'section'     		=> 'enlightme_pro_popular_posts_section',
	'active_callback' 	=> 'enlightme_pro_is_popular_posts_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Popular Posts content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_content_type]', array(
	'default'          	=> $options['popular_posts_content_type'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[popular_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_popular_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_popular_posts_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'enlightme-pro' ),
		'post'      => esc_html__( 'Post', 'enlightme-pro' ),
		'category'  => esc_html__( 'Category', 'enlightme-pro' ),
		),
) );

for ( $i = 1; $i <= $options['popular_posts_count']; $i++ ) :
	// popular_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_popular_posts_section',
		'choices'			=> enlightme_pro_page_choices(),
		'active_callback'	=> 'enlightme_pro_is_popular_posts_section_content_page_enable',
	) ) );

	// popular_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_popular_posts_section',
		'choices'			=> enlightme_pro_post_choices(),
		'active_callback'	=> 'enlightme_pro_is_popular_posts_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'enlightme_pro_theme_options[popular_posts_content_category]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Taxonomies_Control( $wp_customize,'enlightme_pro_theme_options[popular_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'enlightme-pro' ),
	'description'      	=> esc_html__( 'Note: Popular selected no of posts will be shown from selected category', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_popular_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'enlightme_pro_is_popular_posts_section_content_category_enable'
) ) );