<?php
/**
* Slider Section options
*
* @package Theme Palace
* @subpackage Enlightme Pro
* @since Enlightme Pro 1.0.0
*/

// Add Slider section
$wp_customize->add_section( 'enlightme_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','enlightme-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_default_layout( $control )
            ||
            enlightme_pro_is_second_layout( $control )
            ||
            enlightme_pro_is_third_layout( $control )
            ||
            enlightme_pro_is_fourth_layout( $control )
            ||
            enlightme_pro_is_fifth_layout( $control )
        );
    },
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_slider_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider-section .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[slider_section_enable]',
    ) );
}

// Slider content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_slider_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
	'active_callback' 	=> 'enlightme_pro_is_slider_section_enable',
	) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_slider_section',
	'active_callback' 	=> 'enlightme_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#featured-slider-section .read-more a',
		'settings'            => 'enlightme_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_slider_btn_label_partial',
		) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_slider_count',
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_slider_section',
	'active_callback'   => 'enlightme_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
	) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_excerpt_length]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_long_excerpt',
	'default'			=> $options['slider_excerpt_length'],
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'enlightme-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'enlightme-pro' ),
	'section'     		=> 'enlightme_pro_slider_section',
	'active_callback' 	=> 'enlightme_pro_is_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Slider content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'enlightme-pro' ),
		'post' 		=> esc_html__( 'Post', 'enlightme-pro' ),
		'category' 	=> esc_html__( 'Category', 'enlightme-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_sub_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( 'enlightme_pro_theme_options[slider_sub_title_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Sub Title %d', 'enlightme-pro' ), $i ),
	'section'        	=> 'enlightme_pro_slider_section',
	'active_callback' 	=> 'enlightme_pro_is_slider_section_enable',
	'type'				=> 'text',
	) );

// slider pages drop down chooser control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_content_page_' . $i . ']', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'enlightme-pro' ), $i ),
	'section'           => 'enlightme_pro_slider_section',
	'choices'			=> enlightme_pro_page_choices(),
	'active_callback'	=> 'enlightme_pro_is_slider_section_content_page_enable',
	) ) );

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'enlightme-pro' ), $i ),
	'section'           => 'enlightme_pro_slider_section',
	'choices'			=> enlightme_pro_post_choices(),
	'active_callback'	=> 'enlightme_pro_is_slider_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'enlightme_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Taxonomies_Control( $wp_customize,'enlightme_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'enlightme-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'enlightme_pro_is_slider_section_content_category_enable'
	) ) );