<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'enlightme_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','enlightme-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'enlightme-pro' ),
	'panel'             => 'enlightme_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            enlightme_pro_is_default_layout( $control )
            ||
            enlightme_pro_is_second_layout( $control )
            ||
            enlightme_pro_is_fourth_layout( $control )
            ||
            enlightme_pro_is_fifth_layout( $control )
        );
    },
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial-section .tooltiptext',
		'settings'            => 'enlightme_pro_theme_options[testimonial_section_enable]',
    ) );
}

$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_section_buttom_slider_enable]', array(
	'default'			=> 	$options['testimonial_section_buttom_slider_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[testimonial_section_buttom_slider_enable]', array(
	'label'             => esc_html__( 'Show Slider Dots', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'on_off_label' 		=> enlightme_pro_switch_options(),
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
) ) );

$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_section_autoplay_slider_enable]', array(
	'default'			=> 	$options['testimonial_section_autoplay_slider_enable'],
	'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[testimonial_section_autoplay_slider_enable]', array(
	'label'             => esc_html__( 'Autoplay Slider Enable', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
	'on_off_label' 		=> enlightme_pro_switch_options(),
) ) );

// testimonial title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_testimonial_section',
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial-section .section-subtitle',
		'settings'            => 'enlightme_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_testimonial_sub_title_partial',
    ) );
}

// testimonial title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_testimonial_section',
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial-section h2.section-title',
		'settings'            => 'enlightme_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_testimonial_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'enlightme-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'active_callback'   => 'enlightme_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_excerpt_length]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_number_range',
	'validate_callback' => 'enlightme_pro_validate_long_excerpt',
	'default'			=> $options['testimonial_excerpt_length'],
	) );

$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_excerpt_length]', array(
	'label'       		=> esc_html__( 'Testimonial Excerpt Length', 'enlightme-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in testimonial posts.', 'enlightme-pro' ),
	'section'     		=> 'enlightme_pro_testimonial_section',
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'enlightme_pro_sanitize_select',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'enlightme_pro_is_testimonial_section_enable',
	'choices'			=> enlightme_pro_testimonial_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'enlightme_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Enlightme_Pro_Dropdown_Taxonomies_Control( $wp_customize,'enlightme_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'enlightme-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'enlightme-pro' ),
	'section'           => 'enlightme_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'enlightme_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_testimonial_section',
		'choices'			=> enlightme_pro_page_choices(),
		'active_callback'	=> 'enlightme_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'enlightme_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_testimonial_section',
		'choices'			=> enlightme_pro_post_choices(),
		'active_callback'	=> 'enlightme_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Enlightme_Pro_Dropdown_Chooser( $wp_customize, 'enlightme_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonial %d', 'enlightme-pro' ), $i ),
		'section'           => 'enlightme_pro_testimonial_section',
		'choices'			=> enlightme_pro_testimonial_choices(),
		'active_callback'	=> 'enlightme_pro_is_testimonial_section_content_testimonial_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'enlightme_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'position %d', 'enlightme-pro' ), $i ),
		'section'        	=> 'enlightme_pro_testimonial_section',
		'active_callback' 	=> 'enlightme_pro_is_testimonial_position_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'enlightme_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Enlightme_Pro_Customize_Horizontal_Line( $wp_customize, 'enlightme_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'enlightme_pro_testimonial_section',
			'active_callback' => 'enlightme_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

