<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */

// Footer Section
$wp_customize->add_section( 'enlightme_pro_section_footer',
	array(
		'title'      			=> esc_html__( 'Footer Options', 'enlightme-pro' ),
		'priority'   			=> 900,
		'panel'      			=> 'enlightme_pro_theme_options_panel',
	)
);

// footer text
$wp_customize->add_setting( 'enlightme_pro_theme_options[footer_text]',
	array(
		'default'       		=> $options['footer_text'],
		'sanitize_callback'		=> 'enlightme_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);

$wp_customize->add_control( 'enlightme_pro_theme_options[footer_text]',
    array(
		'label'      			=> esc_html__( 'Foote Info Text', 'enlightme-pro' ),
		'section'    			=> 'enlightme_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[footer_text]', array(
		'selector'            => '#colophon h2.section-title',
		'settings'            => 'enlightme_pro_theme_options[footer_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_footer_text_partial',
    ) );
}

// featured title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[footer_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['footer_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[footer_btn_title]', array(
	'label'           	=> esc_html__( 'Footer Btn Label', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_section_footer',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[footer_btn_title]', array(
		'selector'            => '#colophon .read-more a.btn',
		'settings'            => 'enlightme_pro_theme_options[footer_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_footer_btn_title_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'enlightme_pro_theme_options[footer_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'enlightme_pro_theme_options[footer_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'enlightme-pro' ),
	'section'        	=> 'enlightme_pro_section_footer',
	'type'				=> 'url',
) );

// footer image setting and control.
$wp_customize->add_setting( 'enlightme_pro_theme_options[footer_logo]', array(
	'sanitize_callback' => 'enlightme_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'enlightme_pro_theme_options[footer_logo]',
	array(
		'label'       		=> esc_html__( 'Site Footer Logo', 'enlightme-pro' ),
		'section'     		=> 'enlightme_pro_section_footer',
		) ) );

// footer copyright text
$wp_customize->add_setting( 'enlightme_pro_theme_options[copyright_text]',
	array(
		'default'       		=> $options['copyright_text'],
		'sanitize_callback'		=> 'enlightme_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'enlightme_pro_theme_options[copyright_text]',
    array(
		'label'      			=> esc_html__( 'Copyright Text', 'enlightme-pro' ),
		'section'    			=> 'enlightme_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'enlightme_pro_theme_options[copyright_text]', array(
		'selector'            => '#colophon .site-info span.copyright',
		'settings'            => 'enlightme_pro_theme_options[copyright_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'enlightme_pro_copyright_text_partial',
    ) );
}

// scroll top visible
$wp_customize->add_setting( 'enlightme_pro_theme_options[scroll_top_visible]',
	array(
		'default'       		=> $options['scroll_top_visible'],
		'sanitize_callback' => 'enlightme_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Enlightme_Pro_Switch_Control( $wp_customize, 'enlightme_pro_theme_options[scroll_top_visible]',
    array(
		'label'      			=> esc_html__( 'Display Scroll Top Button', 'enlightme-pro' ),
		'section'    			=> 'enlightme_pro_section_footer',
		'on_off_label' 		=> enlightme_pro_switch_options(),
    )
) );