<?php
/**
 * Blog Posts section
 *
 * This is the template for the content of blog_posts section
 *
 * @package Theme Palace
 * @subpackage Enlightme Pro
 * @since Enlightme Pro 1.0.0
 */
if ( ! function_exists( 'enlightme_pro_add_blog_posts_section' ) ) :
    /**
    * Add blog_posts section
    *
    *@since Enlightme Pro 1.0.0
    */
    function enlightme_pro_add_blog_posts_section() {
        $options = enlightme_pro_get_theme_options();
        // Check if blog_posts is enabled on frontpage
        $blog_posts_enable = apply_filters( 'enlightme_pro_section_status', true, 'blog_posts_section_enable' );

        if ( true !== $blog_posts_enable ) {
            return false;
        }
        // Get blog_posts section details
        $section_details = array();
        $section_details = apply_filters( 'enlightme_pro_filter_blog_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog_posts section now.
        enlightme_pro_render_blog_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'enlightme_pro_get_blog_posts_section_details' ) ) :
    /**
    * blog_posts section details.
    *
    * @since Enlightme Pro 1.0.0
    * @param array $input blog_posts section details.
    */
    function enlightme_pro_get_blog_posts_section_details( $input ) {
        $options = enlightme_pro_get_theme_options();

        // Content type.
        $blog_posts_content_type  = $options['blog_posts_content_type'];
        $blog_posts_count = !empty( $options['blog_posts_count'] ) ? $options['blog_posts_count'] : 3;
        $content = array();
        switch ( $blog_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $blog_posts_count; $i++ ) {
                    if ( ! empty( $options['blog_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['blog_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $blog_posts_count; $i++ ) {
                    if ( ! empty( $options['blog_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['blog_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_posts_content_category'] ) ? $options['blog_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = enlightme_pro_trim_content( $options['blog_posts_excerpt_length'] );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog_posts section content details.
add_filter( 'enlightme_pro_filter_blog_posts_section_details', 'enlightme_pro_get_blog_posts_section_details' );


if ( ! function_exists( 'enlightme_pro_render_blog_posts_section' ) ) :
  /**
   * Start blog_posts section
   *
   * @return string blog_posts content
   * @since Enlightme Pro 1.0.0
   *
   */
   function enlightme_pro_render_blog_posts_section( $content_details = array() ) {
        $options = enlightme_pro_get_theme_options();

        $section_sub_title = !empty( $options['blog_posts_sub_title'] ) ? $options['blog_posts_sub_title'] : '';
        $section_title = !empty( $options['blog_posts_title'] ) ? $options['blog_posts_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="enlightme_pro_blog_posts_section" class="relative page-section same-background">

            <div id="blog-latest-posts">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    enlightme_pro_section_tooltip( 'blog-latest-posts' );
                    endif; ?>
                    <div class="section-header">

                        <?php if( !empty( $section_sub_title ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></p>
                        <?php endif;

                        if( !empty( $section_title ) ):
                            ?>
                        <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>

                    <?php endif; ?>

                </div>

                <div class="section-content clear col-3">

                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="blog-post-wrapper">
                                <span class="cat-links">
                                    <?php the_category(',', '', $content['id']); ?>                              
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php enlightme_pro_posted_on( $content['id'] ); ?>

                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if( !empty( $options['blog_posts_btn'] ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['blog_posts_btn'] ); ?></a>
                                    </div><!-- .read-more  -->
                                <?php endif; ?>
                            </div><!-- .blog-post-wrapper -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>  

    </div>     

    <?php }
endif;