<?php
/**
 * Latest Posts section
 *
 * This is the template for the content of latest_posts section
 *
 * @package Theme Palace
 * @subpackage Enlightme Pro
 * @since Enlightme Pro 1.0.0
 */
if ( ! function_exists( 'enlightme_pro_add_latest_posts_section' ) ) :
    /**
    * Add latest_posts section
    *
    *@since Enlightme Pro 1.0.0
    */
    function enlightme_pro_add_latest_posts_section() {
        $options = enlightme_pro_get_theme_options();
        // Check if latest_posts is enabled on frontpage
        $latest_posts_enable = apply_filters( 'enlightme_pro_section_status', true, 'latest_posts_section_enable' );

        if ( true !== $latest_posts_enable ) {
            return false;
        }
        // Get latest_posts section details
        $section_details = array();
        $section_details = apply_filters( 'enlightme_pro_filter_latest_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest_posts section now.
        enlightme_pro_render_latest_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'enlightme_pro_get_latest_posts_section_details' ) ) :
    /**
    * latest_posts section details.
    *
    * @since Enlightme Pro 1.0.0
    * @param array $input latest_posts section details.
    */
    function enlightme_pro_get_latest_posts_section_details( $input ) {
        $options = enlightme_pro_get_theme_options();

        // Content type.
        $latest_posts_content_type  = $options['latest_posts_content_type'];
        $latest_posts_count = !empty( $options['latest_posts_count'] ) ? $options['latest_posts_count'] : 3;
        $content = array();
        switch ( $latest_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $latest_posts_count; $i++ ) {
                    if ( ! empty( $options['latest_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['latest_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $latest_posts_count; $i++ ) {
                    if ( ! empty( $options['latest_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['latest_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $latest_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_posts_content_category'] ) ? $options['latest_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $latest_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = enlightme_pro_trim_content( $options['latest_posts_excerpt_length'] );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_posts section content details.
add_filter( 'enlightme_pro_filter_latest_posts_section_details', 'enlightme_pro_get_latest_posts_section_details' );


if ( ! function_exists( 'enlightme_pro_render_latest_posts_section' ) ) :
  /**
   * Start latest_posts section
   *
   * @return string latest_posts content
   * @since Enlightme Pro 1.0.0
   *
   */
   function enlightme_pro_render_latest_posts_section( $content_details = array() ) {
        $options = enlightme_pro_get_theme_options();

        $section_sub_title = !empty( $options['latest_posts_sub_title'] ) ? $options['latest_posts_sub_title'] : '';
        $section_title = !empty( $options['latest_posts_title'] ) ? $options['latest_posts_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="enlightme_pro_latest_posts_section">
        
        <div id="business-blog-section" class="relative page-section">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                        enlightme_pro_section_tooltip( 'business-blog-section' );
                        endif; ?>
                     <div class="section-header">

                            <?php if( !empty( $section_sub_title ) ): ?>
                                <p class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></p>
                            <?php endif;

                            if( !empty( $section_title ) ):
                                ?>
                            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>

                        <?php endif; ?>

                    </div>

                    <div class="section-content col-3">
                        <div class="archive-blog-wrapper">

                        <?php foreach ( $content_details as $content ) : ?>

                            <article>
                                <div class="popular-post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                           <?php enlightme_pro_posted_on( $content['id'] ); ?>

                                            <span class="cat-links">
                                                <ul class="post-categories">
                                                    <li><?php the_category(',', '', $content['id']); ?></li>
                                                </ul><!-- .post-categories -->
                                            </span><!-- .cat-links -->
                                        </div><!-- .entry-meta -->
                                       
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div>
                                    </div><!-- .entry-container -->
                                </div><!-- .popular-post-wrapper -->
                            </article>

                        <?php endforeach; ?>
     
                        </div>
                    </div><!-- .section-content -->                        
                </div><!-- .wrapper -->
            </div><!-- #business-blog-section -->

            </div>
       
    <?php }
endif;