<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */
if ( ! function_exists( 'enlightme_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since enlightme Pro 1.0.0
    */
    function enlightme_pro_add_testimonial_section() {
        $options = enlightme_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'enlightme_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'enlightme_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        enlightme_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'enlightme_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since enlightme Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function enlightme_pro_get_testimonial_section_details( $input ) {
        $options = enlightme_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;

        $content = array();
        switch ( $testimonial_content_type ) {
            
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'testimonial':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $testimonial_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_testimonial_' . $i] ) ) :
                        $testimonial_ids[] = $options['testimonial_content_testimonial_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-testimonial',
                    'post__in'          => ( array ) $testimonial_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['position']  = !empty( $position[$i] ) ? $position[$i] : '';
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = enlightme_pro_trim_content( $options['testimonial_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
        
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'enlightme_pro_filter_testimonial_section_details', 'enlightme_pro_get_testimonial_section_details' );


if ( ! function_exists( 'enlightme_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since enlightme Pro 1.0.0
   *
   */
   function enlightme_pro_render_testimonial_section( $content_details = array() ) {
        $options = enlightme_pro_get_theme_options();
        $testimonial_autoplay = (bool) ($options['testimonial_section_autoplay_slider_enable']) ? 'true' : 'false';
        $testimonial_button_slider = (bool) ($options['testimonial_section_buttom_slider_enable']) ? 'true' : 'false';
        $testimonial_content_type  = $options['testimonial_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="enlightme_pro_testimonial_section">

        <div id="testimonial-section" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                enlightme_pro_section_tooltip( 'testimonial-section' );
                endif; ?>
                <div class="section-header">
                    <?php if ( !empty( $options['testimonial_sub_title'] ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['testimonial_sub_title'] ); ?></p>
                    <?php endif ?>
                    <?php if ( !empty( $options['testimonial_title'] ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $options['testimonial_title'] ); ?></h2>
                    <?php endif ?>                    
                </div><!-- .section-header -->

                <div class="testimonial-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": <?php echo esc_attr( $testimonial_button_slider ); ?>, "arrows":false, "autoplay": <?php echo esc_attr( $testimonial_autoplay ); ?>, "draggable": true, "fade": false }'>
                    <?php $i = 1; foreach ( $content_details as $content ): ?>
                    <article>
                        <div class="testimonial-item">
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" title="<?php echo esc_attr( $content['title'] ) ; ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" attr="<?php echo esc_attr( $content['title'] ) ; ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container clear">

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                                </div><!-- .entry-content -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>" title="<?php echo esc_attr( $content['title'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                    <?php if( $testimonial_content_type !== 'testimonial' ){ ?>
                                    <?php if( !empty( $options['testimonial_position_'.$i] ) ): ?>
                                    <span class="testimonial-position"><?php echo esc_html( $options['testimonial_position_'.$i] ) ?></span>
                                <?php endif; ?>
                                <?php }else{ ?>
                                <?php enlightme_pro_testimonial_designation( $content['id'] ); ?>
                                    <?php
                                    } ?>
                                </header>

                                 <?php if( $testimonial_content_type == 'testimonial' ){ ?>
                                <div class="user-rating">
                                   <?php tp_testimonial_rating( $content['id'] ); ?>
                                </div><!-- .user-rating -->
                                <?php } ?>
                            </div><!-- .entry-container -->
                        </div><!-- .testimonial-item -->
                    </article>
                    <?php $i++; endforeach ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #testimonial-section -->

        </div>
        
    <?php }
endif;