<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage enlightme Pro
 * @since enlightme Pro 1.0.0
 */

$options = enlightme_pro_get_theme_options();


if ( ! function_exists( 'enlightme_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since enlightme Pro 1.0.0
	 */
	function enlightme_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'enlightme_pro_doctype', 'enlightme_pro_doctype', 10 );


if ( ! function_exists( 'enlightme_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'enlightme_pro_before_wp_head', 'enlightme_pro_head', 10 );

if ( ! function_exists( 'enlightme_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'enlightme-pro' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'enlightme_pro_page_start_action', 'enlightme_pro_page_start', 10 );

if ( ! function_exists( 'enlightme_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'enlightme_pro_page_end_action', 'enlightme_pro_page_end', 10 );



if ( ! function_exists( 'enlightme_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_header_start() { 
		$options  = enlightme_pro_get_theme_options();
	?>
		<header id="masthead" class="site-header" role="banner">
			<?php if ( $options['topbar_section_enable'] == true ): ?>
			<div id="top-bar" class="relative">
	            <div class="wrapper">
	                <div class="col-2 clear">
	                    <div class="hentry">
	                        <ul class="contact-info clear">
	                            <li>
	                            	<a href="tel:<?php echo esc_attr( $options['topbar_field_1'] ) ; ?>">          
	                            		<?php echo enlightme_pro_get_svg( array( 'icon' => 'phone' ) ) ; ?>
		                                <?php
		                                	echo esc_html( $options['topbar_field_1'] ) ;
		                                ?>
	                               </a>
	                            </li>
	                            <li>
	                            	<a href="mailto:<?php echo esc_attr( $options['topbar_field_2'] ) ; ?>">                                	         
		                                <?php echo enlightme_pro_get_svg( array( 'icon' => 'message' ) ) ; ?>
		                                <?php
		                                	echo esc_html( $options['topbar_field_2'] ) ;
		                                ?>
	                               </a>
	                            </li>
	                        </ul><!-- .contact-info -->
	                    </div><!-- .hentry -->

	                    <div class="hentry">
	                        <div class="secondary-menu">
	                        	<?php if ( $options['social_menu_enable'] == true && has_nav_menu('social')):   

				            		wp_nav_menu( array(
				            			'theme_location' => 'social',
				            			'container' => false,
				            			'menu_class' => 'social-icons',
				            			'echo' => true,
				            			'fallback_cb' => false,
				            			'depth' => 1,
				            			'link_before' => '<span class="screen-reader-text">',
										'link_after' => '</span>',
				            		 ) );
				            	endif; 
				            	if( $options['topbar_btn'] == true && (  ! empty ( $options['topbar_btn_url'] ) && ! empty( ! empty ( $options['topbar_btn_title'] ) ) ) ): ?>
				            		<a href="<?php echo $options['topbar_btn_url'] ; ?>" class="apply-now">
				            			<?php echo $options['topbar_btn_title'] ; ?>
				            		</a>
				            	<?php endif ?>
	                            
	                        </div><!-- .secondary-menu -->
	                    </div><!-- .hentry -->
	                </div><!-- .col-2 -->
	            </div><!-- .wrapper -->
	        </div><!-- #top-bar -->
	        <?php endif; ?>
			<div class="wrapper main-menu">
		<?php
	}
endif;
add_action( 'enlightme_pro_header_action', 'enlightme_pro_header_start', 20 );

if ( ! function_exists( 'enlightme_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_site_branding() {
		$options  = enlightme_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>		
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-details">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( enlightme_pro_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
	    	<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'enlightme_pro_header_action', 'enlightme_pro_site_branding', 20 );

if ( ! function_exists( 'enlightme_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_site_navigation() {
		$options = enlightme_pro_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<span class="menu-label"><?php esc_html_e( 'Menu', 'enlightme-pro' ); ?></span>			
				<?php
				echo enlightme_pro_get_svg( array( 'icon' => 'menu' ) );
				echo enlightme_pro_get_svg( array( 'icon' => 'close' ) );
				?>		
			</button>
				<?php 
					$search = '';
					if ( $options['menu_search'] ) :
						$search = '<li class="search-menu">';
						$search .= '<a href="#" class="">';
						$search .= enlightme_pro_get_svg( array( 'icon' => 'search' ) );
						$search .= enlightme_pro_get_svg( array( 'icon' => 'close' ) );
						$search .= '</a><div id="search" style="display: none;">';
						$search .= get_search_form( $echo = false );
		                $search .= '</div></li>';
	                endif;
	        	
	        		wp_nav_menu(array(
	        			'theme_location' => 'primary',
	        			'container' => 'div',
	        			'menu_class' => 'menu nav-menu',
	        			'menu_id' => 'primary-menu',
	        			'echo' => true,
	        			'fallback_cb' => 'enlightme_pro_menu_fallback_cb',
	        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
	        		));
	        	?>
        	</div><!-- .wrapper -->
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'enlightme_pro_header_action', 'enlightme_pro_site_navigation', 30 );


if ( ! function_exists( 'enlightme_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_header_end() {
		?>
			</div>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'enlightme_pro_header_action', 'enlightme_pro_header_end', 50 );

if ( ! function_exists( 'enlightme_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'enlightme_pro_content_start_action', 'enlightme_pro_content_start', 10 );

if ( ! function_exists( 'enlightme_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_header_image() {
		if ( enlightme_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php echo enlightme_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php enlightme_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->
		<?php
	}
endif;
add_action( 'enlightme_pro_header_image_action', 'enlightme_pro_header_image', 10 );

if ( ! function_exists( 'enlightme_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since enlightme Pro 1.0.0
	 */
	function enlightme_pro_add_breadcrumb() {
		$options = enlightme_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( enlightme_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list">';
				/**
				 * enlightme_pro_simple_breadcrumb hook
				 *
				 * @hooked enlightme_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'enlightme_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;
add_action( 'enlightme_pro_header_image_action', 'enlightme_pro_add_breadcrumb', 20 );

if ( ! function_exists( 'enlightme_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_content_end() {
		?>
			
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'enlightme_pro_content_end_action', 'enlightme_pro_content_end', 10 );

if ( ! function_exists( 'enlightme_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_footer_start() {
		$options = enlightme_pro_get_theme_options();
	?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			<div class="footer-text-wrapper wrapper clear">
				<?php if ( ! empty( $options['footer_text'] ) ): ?>
					<div class="section-header-wrapper">
	                    <div class="section-header">
	                        <h2 class="section-title"><?php echo esc_html( $options['footer_text'] ); ?></h2>
	                    </div><!-- .section-header -->
	                </div>
				<?php endif ?>
               	
               	<?php if ( ! empty( $options['footer_btn_title'] ) && !empty( $options['footer_btn_url'] ) ): ?>
               		<div class="read-more">
	                    <a href="<?php echo esc_url( $options['footer_btn_url'] ); ?>" class="btn" tabindex="0"><?php echo esc_html( $options['footer_btn_title'] ); ?></a>
	                </div>
               	<?php endif ?>               
            </div>
		<?php
	}
endif;
add_action( 'enlightme_pro_footer', 'enlightme_pro_footer_start', 10 );

if ( ! function_exists( 'enlightme_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_footer_site_info() {
		$options = enlightme_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		
		<div class="site-info <?php echo ($options['footer_logo'] == '' ? 'col-1' : 'col-2'); ?>">
			<div class="wrapper">
				<?php if( !empty( $options['footer_logo'] ) ): ?>
					<span><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $options['footer_logo'] ); ?>" alt="<?php bloginfo( 'name' ); ?>"></a></span>
				<?php endif;
				if( !empty( $copyright_text ) ):
					?>
				<span class="copyright">
					<?php echo enlightme_pro_santize_allow_tag( $copyright_text ); ?>
				</span>
			<?php endif; ?>
		</div><!-- .wrapper -->    
	</div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'enlightme_pro_footer', 'enlightme_pro_footer_site_info', 40 );

if ( ! function_exists( 'enlightme_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_footer_scroll_to_top() {
		$options  = enlightme_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo enlightme_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'enlightme_pro_footer', 'enlightme_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'enlightme_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'enlightme_pro_footer', 'enlightme_pro_footer_end', 100 );

if ( ! function_exists( 'enlightme_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_loader() {
		$options = enlightme_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo enlightme_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
        <div class="menu-overlay"></div>
		<?php }
	}
endif;
add_action( 'enlightme_pro_before_header', 'enlightme_pro_loader', 10 );

if ( ! function_exists( 'enlightme_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since enlightme Pro 1.0.0
	 *
	 */
	function enlightme_pro_infinite_loader_spinner() { 
		$id = get_the_ID();
		$options = enlightme_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( ! empty( $id ) ) {
				echo '<div class="blog-loader">' . enlightme_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'enlightme_pro_infinite_loader_spinner_action', 'enlightme_pro_infinite_loader_spinner', 10 );
